@@ -1,4 +1,4 @@
-<?xml version="1.0"?>
+<?xml version="1.0" encoding="UTF-8"?>
 <app>
 
 <category>
@@ -42,13 +42,15 @@ Assamese_Default_Firefox_esr
    <ja>アッサム語版 Firefox-ESR</ja>
    <kk>Assamese localisation of Firefox-ESR</kk>
    <ko>Assamese localisation of Firefox-ESR</ko>
+   <ku>Assamese localisation of Firefox-ESR</ku>
    <lt>Assamese localisation of Firefox-ESR</lt>
    <mk>Assamese localisation of Firefox-ESR</mk>
    <mr>Assamese localisation of Firefox-ESR</mr>
    <nb_NO>Assamese localisation of Firefox-ESR</nb_NO>
    <nb>Assamesisk lokaltilpassing av Firefox ESR</nb>
    <nl_BE>Assamese localisation of Firefox-ESR</nl_BE>
-   <nl>Assamese localisation of Firefox-ESR</nl>
+   <nl>Assamees lokalisatie van Firefox-ESR</nl>
+   <or>Assamese localisation of Firefox-ESR</or>
    <pl>Assamese localisation of Firefox-ESR</pl>
    <pt_BR>Assamês Localização para o Firefox ESR</pt_BR>
    <pt>Assamês Localização para Firefox ESR</pt>
@@ -56,6 +58,7 @@ Assamese_Default_Firefox_esr
    <ru>Assamese localisation of Firefox-ESR</ru>
    <sk>Assamese localisation of Firefox-ESR</sk>
    <sl>Asamejske krajevne nastavitve za Firefox-ESR</sl>
+   <so>Assamese localisation of Firefox-ESR</so>
    <sq>Përkthimi i Firefox-it ESR në asamisht</sq>
    <sr>Assamese localisation of Firefox-ESR</sr>
    <sv>Assamesisk lokalisering av Firefox-ESR</sv>
