@@ -1,4 +1,4 @@
-<?xml version="1.0"?>
+<?xml version="1.0" encoding="UTF-8"?>
 <app>
 
 <category>
@@ -42,13 +42,15 @@ English (Australia)
    <ja>Hunspell 用英語（オーストラリア）辞書</ja>
    <kk>English (Australian) dictionary for hunspell</kk>
    <ko>English (Australian) dictionary for hunspell</ko>
+   <ku>English (Australian) dictionary for hunspell</ku>
    <lt>English (Australian) dictionary for hunspell</lt>
    <mk>English (Australian) dictionary for hunspell</mk>
    <mr>English (Australian) dictionary for hunspell</mr>
    <nb_NO>English (Australian) dictionary for hunspell</nb_NO>
    <nb>Engelsk (australsk) ordliste for hunspell</nb>
    <nl_BE>English (Australian) dictionary for hunspell</nl_BE>
-   <nl>English (Australian) dictionary for hunspell</nl>
+   <nl>Engels (Australisch) woordenboek voor hunspell</nl>
+   <or>English (Australian) dictionary for hunspell</or>
    <pl>English (Australian) dictionary for hunspell</pl>
    <pt_BR>Dicionário Inglês (Australiano) para o hunspell (corretor ortográfico e analisador morfológico)</pt_BR>
    <pt>Dicionário Inglês (Australiano) para hunspell</pt>
@@ -56,6 +58,7 @@ English (Australia)
    <ru>English (Australian) dictionary for hunspell</ru>
    <sk>English (Australian) dictionary for hunspell</sk>
    <sl>Angleški (avstralska) slovar za hunspell</sl>
+   <so>English (Australian) dictionary for hunspell</so>
    <sq>Fjalor anglisht (Australie) për hunspell</sq>
    <sr>English (Australian) dictionary for hunspell</sr>
    <sv>Engelsk (Australisk) ordbok för hunspell</sv>
